use strict;
use warnings;
use v5.20;
use utf8;

return [
  {
    'author' => [
      'Dominique Dumont'
    ],
    'class_description' => 'Swap options',
    'copyright' => [
      '2010,2011 Dominique Dumont'
    ],
    'element' => [
      'sw',
      {
        'type' => 'leaf',
        'value_type' => 'boolean'
      }
    ],
    'license' => 'LGPL2',
    'name' => 'Fstab::SwapOptions'
  }
]
;
